<template>
  <div class="app-container">
    <!-- 搜索表单 -->
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="文件名" prop="fileName">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入文件名"
          clearable
          size="default"
          @keyup.enter="handleQuery"
        />
      </el-form-item>
      <el-form-item label="文件类别" prop="type">
          <el-select v-model="queryParams.type" placeholder="请选择文件类别" style="width: 180px;">
            <el-option label="片头" :value="VIDEO_TYPE.HEAD" />
            <el-option label="片尾" :value="VIDEO_TYPE.TAIL" />
          </el-select>
        </el-form-item>
      <el-form-item>
        <el-button type="primary" size="default" @click="handleQuery" :icon="Search">搜索</el-button>
        <el-button size="default" @click="resetQuery" :icon="Refresh">重置</el-button>
        <el-button
          type="primary"
          size="default"
          @click="handleAdd"
          :icon="Plus"
        >新增</el-button>
      </el-form-item>
    </el-form>

    <!-- 表格 -->
    <el-table v-loading="loading" :data="fileList">
      <el-table-column type="index" label="序号" align="center" width="80" />
      <el-table-column label="文件名" prop="name" :show-overflow-tooltip="true" align="center" />
      <el-table-column label="文件类别" prop="type" align="center">
        <template #default="scope">
          {{ scope.row.type === VIDEO_TYPE.HEAD ? '片头' : '片尾' }}
        </template>
      </el-table-column>
      <el-table-column label="创建人" prop="creatorName" align="center" />
      <el-table-column label="创建时间" prop="createTime" align="center">
        <template #default="scope">
          <span>{{ parseTime(scope.row.createTime) }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template #default="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-view"
            @click="handlePreview(scope.row.url)"
          >预览</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-download"
            @click="handleDownload(scope.row.url,scope.row.name)"
          >下载</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            style="color: #F56C6C"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <!-- 分页 -->
    <pagination
      v-show="total>0"
      :total="total"
      v-model:page="queryParams.pageNo"
      v-model:limit="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 新增弹窗 -->
    <el-dialog :title="dialogTitle" v-model="open" width="40%" append-to-body>
      <el-form ref="formRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="文件名" prop="name">
          <el-input v-model="form.name" placeholder="请输入文件名" />
        </el-form-item>
        <el-form-item label="文件类别" prop="type">
          <el-select v-model="form.type" placeholder="请选择文件类别">
            <el-option label="片头" :value="VIDEO_TYPE.HEAD" />
            <el-option label="片尾" :value="VIDEO_TYPE.TAIL" />
          </el-select>
        </el-form-item>
        <el-form-item label="上传文件" prop="url">
          <UploadFile v-model="form.url" :fileType="['mp4']" :limit="1" @on-success="handleFileSuccess('videoUrl', $event)"/>
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>

    <!-- 视频预览弹窗 -->
    <el-dialog title="视频预览" v-model="previewVisible" width="50%" append-to-body>
      <video
        v-if="previewUrl"
        :src="previewUrl"
        controls
        style="width: 100%"
      >您的浏览器不支持 video 标签。</video>
    </el-dialog>
  </div>
</template>

<script lang="ts" setup>
import { ref, reactive, onMounted } from 'vue'
import type { FormInstance } from 'element-plus'
import  * as DigitalHumansApi from '@/api/system/file/index'
import dayjs from 'dayjs'
const message = useMessage() // 消息弹窗
import {
  Refresh,
  Search,
  Plus,
} from '@element-plus/icons-vue'
// 视频类别常量
const VIDEO_TYPE = {
  HEAD: '1', // 片头
  TAIL: '2'  // 片尾
}

interface FileItem {
  id?: number
  name: string
  type: string
  createBy?: string
  url: string
}

interface QueryParams {
  pageNo: number
  pageSize: number
  name?: string
  type?: string
}

// 遮罩层
const loading = ref(true)
// 显示搜索条件
const showSearch = ref(true)
// 总条数
const total = ref(0)
// 文件列表
const fileList = ref<FileItem[]>([])
// 查询参数
const queryParams = reactive<QueryParams>({
  pageNo: 1,
  pageSize: 10,
  name: undefined,
  type: ''
})

// 表单引用
const formRef = ref<FormInstance>()

// 新增弹窗
const open = ref(false)
const dialogTitle = ref('新增文件')
const form = reactive<FileItem>({
  id: undefined,
  name: '',
  url: '',
  type: '',
  createBy: undefined
})
const rules = reactive({
  name: [
    { required: true, message: "文件名不能为空", trigger: "blur" }
  ],
  type: [
    { required: true, message: "请选择文件类别", trigger: "change" }
  ],
  url: [
    { required: true, message: "请上传文件", trigger: "change" }
  ]
})

// 预览弹窗
const previewVisible = ref(false)
const previewUrl = ref('')

// 新增按钮操作
const handleAdd = () => {
  form.id = undefined
  form.name = ''
  form.url = ''
  form.type = ''
  form.createBy = undefined
  dialogTitle.value = '新增文件'
  if (formRef.value) {
    formRef.value.resetFields()
  }
  open.value = true
}

// 取消按钮
const cancel = () => {
  open.value = false
  reset()
}

// 表单重置
const reset = () => {
  form.id = undefined
  form.name = ''
  form.url = ''
  form.type = ''
  form.createBy = undefined
  dialogTitle.value = '新增文件'
  if (formRef.value) {
    formRef.value.resetFields()
  }
}

// 提交按钮
const submitForm = async () => {
  if (!formRef.value) return
  try {
    await formRef.value.validate()
    // 验证通过，执行提交操作
    let res
    if (form.id) {
      // 修改操作
      res = await DigitalHumansApi.updateFile(form)
    } else {
      // 新增操作
      res = await DigitalHumansApi.createFile(form)
    }
    console.log(res)
    open.value = false
    if (res) {
      message.success(form.id ? "修改成功" : "新增成功")
      reset()
      getList()
    }
  } catch (error) {
    // 验证失败，显示错误信息
    message.error("请填写完整信息")
  }
}
const handleFileSuccess = (fileType,response) => {
  if (fileType === 'videoUrl') {
    form.url = response.data;
  }
};
// 查询文件列表
const getList = async () => {
  loading.value = true
  try {
    const data = await DigitalHumansApi.listFile(queryParams)
    console.log(data)
    fileList.value = data.list
    total.value = data.total
  } finally {
    loading.value = false
  }
}

// 搜索按钮操作
const handleQuery = () => {
  queryParams.pageNo = 1
  getList()
}

// 重置按钮操作
const resetQuery = () => {
  queryParams.name = undefined
  queryParams.type = ''
  handleQuery()
}

// 修改按钮操作
const handleUpdate = (row: FileItem) => {
  form.id = row.id
  form.name = row.name || ''
  form.url = row.url || ''
  form.type = row.type
  form.createBy = row.createBy
  dialogTitle.value = '修改文件'
  open.value = true
}

// 删除按钮操作
const handleDelete = async (row: FileItem) => {
  await message.delConfirm()
  if (row.id) {
    const res = await DigitalHumansApi.deleteFile(row.id)
    if (res) {
      message.success("删除成功")
      getList()
    }
  }
}

// 下载按钮操作
const handleDownload = (url, filename) => {
  if (!url) {
    message.warning("未找到资源文件！")
    return
  }
  console.log(url,filename)
  const link = document.createElement('a')
  link.href = url
  link.download = filename || 'download'
  link.target = '_blank'
  document.body.appendChild(link)
  link.click()
  document.body.removeChild(link)
}

// 预览按钮操作
const handlePreview = (url: string) => {
  if (!url) {
    message.warning("未找到资源文件！")
    return
  }
  previewUrl.value = url
  previewVisible.value = true
}

// 格式化时间
const parseTime = (time: number) => {
  return dayjs(time).format('YYYY-MM-DD HH:mm:ss')
}

onMounted(() => {
  getList()
})
</script>

<style scoped>
.app-container {
  padding: 20px;
}
.mb8 {
  margin-bottom: 8px;
}
</style>
